@@ -1,7 +1,7 @@
 
 /*
  *  agUtils.c
- *  $Id: agUtils.c,v 3.6 2002/03/27 04:45:29 bkorb Exp $
+ *  $Id: agUtils.c,v 1.22 2002/09/20 04:56:44 bkorb Exp $
  *  This is the main routine for autogen.
  */
 
@@ -566,214 +566,6 @@ skipExpression( tCC* pzSrc, size_t len )
     while (! isspace( *pzSrc ))  pzSrc++;
     return (pzSrc > pzEnd) ? pzEnd : pzSrc;
 }
-
-
-#ifndef MEMDEBUG
-
-
-    void*
-ag_alloc( size_t sz, tCC* pzWhat )
-{
-    void* p = malloc( sz );
-    if ((p == NULL) && (pzWhat != NULL))
-        AG_ABEND( asprintf( zAllocErr, pzProg, sz, pzWhat ));
-    return p;
-}
-
-
-    void*
-ag_realloc( void* p, size_t sz, tCC* pzWhat )
-{
-    void* np = p ? realloc( p, sz ) : malloc( sz );
-    if (np == NULL) {
-        if (pzWhat != NULL)
-            AG_ABEND( asprintf( zAllocErr, pzProg, sz, pzWhat ));
-
-        if (p != NULL)
-            free( p );
-    }
-
-    return np;
-}
-
-
-    char*
-ag_strdup( tCC* pz, tCC* pzWhat )
-{
-    char*   pzRes;
-    size_t  len = strlen( pz )+1;
-
-    /*
-     *  There are some systems out there where autogen is
-     *  broken if "strdup" is allowed to duplicate strings
-     *  smaller than 32 bytes.  This ensures that we work.
-     *  We also round up everything up to 32 bytes.
-     */
-    if (len < 0x20)
-         len = 0x20;
-    else len = (len + 0x20) & ~0x1F;
-
-    pzRes = ag_alloc( len, pzWhat );
-
-    if (pzRes != NULL)
-        strcpy( pzRes, pz );
-
-    return pzRes;
-}
-
-#else
-STATIC tMemMgmt memHead = { &memHead, &memHead, NULL, "ROOT" };
-#define CHECK_CT 128
-#define SPARE    128
-
-
-    void*
-ag_alloc( size_t sz, tCC* pzWhat, tCC* pz )
-{
-    size_t    asz = sz + sizeof( tMemMgmt ) + CHECK_CT + SPARE;
-    tMemMgmt* p = (tMemMgmt*)malloc( asz & ~0x3F );
-
-    if (p == NULL) {
-        if (pzWhat == NULL)
-            return NULL;
-
-        pzWhat = asprintf( zAllocErr, pzProg, sz, pzWhat );
-        AG_ABEND( pzWhat );
-    }
-
-    /*
-     *  Link new entry to end of chain
-     */
-    p->pPrev        = memHead.pPrev;
-    p->pPrev->pNext = p;
-    memHead.pPrev   = p;
-    p->pNext        = &memHead;
-
-    p->pEnd = ((char*)(p+1)) + sz;
-    memset( (void*)p->pEnd, '~', CHECK_CT );
-    p->pzWhence = pz;
-
-    return (void*)(p+1);
-}
-
-
-    void*
-ag_realloc( void* p, size_t sz, tCC* pzWhat, tCC* pz )
-{
-    size_t      asz = sz + sizeof( tMemMgmt ) + CHECK_CT + SPARE;
-    tMemMgmt*   np  = ((tMemMgmt*)p)-1;
-    tMemMgmt    sv  = *np;
-
-    checkMem( np );
-    np = (tMemMgmt*)(p ? realloc( (void*)np, asz & ~0x3F )
-                       : malloc( asz & ~0x3F ));
-
-    if (np == NULL) {
-        if (pzWhat == NULL) {
-            if (p != NULL)
-                free( (void*)p );
-
-            /*
-             *  Unlink old entry
-             */
-            sv.pPrev->pNext = sv.pNext;
-            sv.pNext->pPrev = sv.pPrev;
-            return NULL;
-        }
-
-        AG_ABEND( asprintf( zAllocErr, pzProg, sz, pzWhat ));
-    }
-
-    /*
-     *  Link other entries to new allocation
-     */
-    np->pPrev->pNext = np;
-    np->pNext->pPrev = np;
-
-    np->pEnd = ((char*)(np+1)) + sz;
-    memset( (void*)np->pEnd, '~', CHECK_CT );
-    np->pzWhence = pz;
-
-    return (void*)(np+1);
-}
-
-
-STATIC void
-checkMem( tMemMgmt* pMM )
-{
-    char* p  = pMM->pEnd;
-    int   ct = CHECK_CT;
-
-    do  {
-        if (*(p++) != '~') {
-            fprintf( pfTrace, "Stray pointer %d bytes after %d-byte %s end\n",
-                     CHECK_CT - ct, pMM->pEnd - (char*)(pMM+1),
-                     pMM->pzWhence );
-            fclose( stderr );
-            fclose( pfTrace );
-            fclose( stdout );
-            p = NULL;
-            *p = '~'; /* SEG FAULT */
-            _exit( EXIT_FAILURE );
-        }
-    } while (--ct > 0);
-}
-
-
-    void
-ag_free( void* p )
-{
-    tMemMgmt*   np  = ((tMemMgmt*)p)-1;
-    checkMem( np );
-
-    /*
-     *  Unlink old entry
-     */
-    np->pPrev->pNext = np->pNext;
-    np->pNext->pPrev = np->pPrev;
-    free( (void*)np );
-}
-
-
-STATIC void
-finalMemCheck( void )
-{
-    tMemMgmt*  pMM = memHead.pNext;
-
-    fputs( "\nResidual allocation list:\n", pfTrace );
-    while (pMM != &memHead) {
-        checkMem( pMM );
-        fprintf( pfTrace, "%12d bytes from %s\n",
-                 pMM->pEnd - (char*)(pMM+1), pMM->pzWhence );
-        pMM = pMM->pNext;
-    }
-}
-
-
-    char*
-ag_strdup( tCC* pz, tCC* pzDupFrom, tCC* pzWhat )
-{
-    char*   pzRes;
-    size_t  len = strlen( pz )+1;
-
-    /*
-     *  There are some systems out there where autogen is
-     *  broken if "strdup" is allowed to duplicate strings
-     *  smaller than 32 bytes.  This ensures that we work.
-     *  We also round up everything up to 32 bytes.
-     */
-    if (len < 0x20)
-         len = 0x20;
-    else len = (len + 0x20) & ~0x1F;
-
-    pzRes = ag_alloc( len, pzWhat, pzDupFrom );
-
-    if (pzRes != NULL)
-        strcpy( pzRes, pz );
-
-    return pzRes;
-}
-#endif
 /*
  * Local Variables:
  * c-file-style: "stroustrup"
