@@ -1,6 +1,6 @@
 
 /*
- *  $Id: streqv.h,v 3.1 2002/03/29 02:22:17 bkorb Exp $
+ *  $Id: streqv.h,v 2.7 2002/09/20 04:56:45 bkorb Exp $
  *
  *  String Equivalence
  *
@@ -56,8 +56,7 @@
 #ifndef TOOLS_STREQUIVALENCE
 #define TOOLS_STREQUIVALENCE
 
-#include <sys/types.h>
-#include "options.h"
+#include "autoopts.h"
 
 /* strneqvcmp
  *
