@@ -2,12 +2,12 @@
 ##  -*- Mode: shell-script -*-
 ## mklibsrc.sh --   make the libopts tear-off library source tarball
 ##
-## Time-stamp:      "2002-08-23 20:09:20 bkorb"
+## Time-stamp:      "2002-09-21 15:22:33 bkorb"
 ## Maintainer:      Bruce Korb <bkorb@gnu.org>
 ## Created:         Aug 20, 2002
 ##              by: bkorb
 ## ---------------------------------------------------------------------
-## $Id: mklibsrc.sh,v 1.10 2002/08/24 03:14:49 bkorb Exp $
+## $Id: mklibsrc.sh,v 1.14 2002/09/21 22:24:35 bkorb Exp $
 ## ---------------------------------------------------------------------
 ## Code:
 
@@ -23,9 +23,12 @@ cd ${top_builddir}/pkg
 mkdir ${tag}
 mkdir ${tag}/compat
 
-cd ../autoopts
+# # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # #
+#
+#  WORKING IN SOURCE DIRECTORY
+#
+cd ${top_srcdir}/autoopts
 cp -f autoopts.c     \
-      autoopts.h     \
       boolean.c      \
       enumeration.c  \
       numeric.c      \
@@ -35,27 +38,38 @@ cp -f autoopts.c     \
       save.c         \
       stack.c        \
       streqv.h       \
-      streqvcmp.c    \
       usage.c        \
       version.c      \
-  ../pkg/${tag}/.
+  ${top_builddir}/pkg/${tag}/.
 
-cp -f COPYING ../pkg/${tag}/COPYING.lgpl
+cp -f COPYING ${top_builddir}/pkg/${tag}/COPYING.lgpl
+
+sed '/#ifdef AUTOGEN_BUILD/,/#endif.* AUTOGEN_BUILD/d' streqvcmp.c > \
+  ${top_builddir}/pkg/${tag}/streqvcmp.c
+
+sed '/broken printf/,/our own/d
+     /include.*"snprintfv/d
+     /#ifndef AUTOGEN_BUILD/d
+     /#else.* AUTOGEN_BUILD/,/#endif.* AUTOGEN_BUILD/d' autoopts.h > \
+  ${top_builddir}/pkg/${tag}/autoopts.h
 
 cd ../compat
-cp *.h pathfind.c ../pkg/${tag}/compat/.
+cp pathfind.c compat.h ${top_builddir}/pkg/${tag}/compat/.
+#
+#  END WORK IN SOURCE DIRECTORY
+#
+# # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # #
 
-cd ../pkg/${tag}
+cd ${top_builddir}/pkg/${tag}
 
-files=`ls -1 *.[ch] | \
-	${top_builddir}/columns/columns -I4 --spread=1 --line='  \\' `
+${top_builddir}/agen5/autogen -L ${top_srcdir}/config --writable <<-	'_EOF_'
 
-ag="${top_builddir}/agen5/autogen -L ${top_srcdir}/config --writable"
-( echo "autogen definitions conftest.tpl;"
-  echo "output-file = libopts.m4;"
-  echo "group       = libopts;"
-  cat ${top_srcdir}/config/libopts.def
-) | $ag -DLIBOPTS=1
+	autogen definitions conftest.tpl;
+	output-file = libopts.m4;
+	group       = libopts;
+	#define       LIBOPTS  1
+	#include      libopts.def
+	_EOF_
 
 cat >> libopts.m4 <<-	EOMacro
 
@@ -66,6 +80,9 @@ cat >> libopts.m4 <<-	EOMacro
 	dnl to SUBDIRS and run all the config tests that the library needs.
 	dnl
 	AC_DEFUN([LIBOPTS_CHECK],[
+	`sed -n '/Check for standard headers/,/gen, pathfind/p' \
+	     ${top_srcdir}/configure.in`
+
 	  AC_MSG_CHECKING([whether autoopts-config can be found])
 	  AC_ARG_WITH([autoopts-config],
         AC_HELP_STRING([--with-autoopts-config],
@@ -100,23 +117,13 @@ cat >> libopts.m4 <<-	EOMacro
 	  AM_CONDITIONAL([NEED_LIBOPTS], [test -n "\${build_libopts_dir}"])
 	  AC_SUBST(LIBOPTS_LDADD)
 	  AC_SUBST(LIBOPTS_CFLAGS)
+	  AC_CONFIG_FILES([libopts/Makefile])
 	]) # end of AC_DEFUN of LIBOPTS_CHECK
 	EOMacro
 
 [ -f Makefile.am ] && rm -f Makefile.am
 
-cat > Makefile.am <<-	EOMakefile
-
-	MAINTAINERCLEANFILES = Makefile.in
-	INCLUDES = @INCLIST@
-	SRC      = \\
-	$files
-	lib_LTLIBRARIES = libopts.la
-	libopts_la_SOURCES = \$(SRC)
-	EOMakefile
-
 cat > MakeDefs.inc <<-	EOMakeDefs
-
 	## LIBOPTS Makefile Fragment
 	if NEED_LIBOPTS
 	  LIBOPTS_DIR  = libopts
@@ -127,8 +134,22 @@ cat > MakeDefs.inc <<-	EOMakeDefs
 	LIBOPTS_CFLAGS = @LIBOPTS_CFLAGS@
 	EOMakeDefs
 
-sed s,'\${tag}',"${tag}",g ../libopts/README > README
-cp ../libopts/COPYING* .
+sed s,'\${tag}',"${tag}",g ${top_srcdir}/pkg/libopts/README > README
+cp ${top_srcdir}/pkg/libopts/COPYING* .
+
+exec 3> Makefile.am
+cat >&3 <<-	EOMakefile
+	## LIBOPTS Makefile
+	EXTRA_DIST            = `echo COPYING*` MakeDefs.inc compat
+	MAINTAINERCLEANFILES  = Makefile.in
+	lib_LTLIBRARIES       = libopts.la
+	libopts_la_SOURCES    = \\
+	EOMakefile
+
+ls -1 *.[ch] | \
+  ${top_builddir}/columns/columns -I4 --spread=1 --line-sep='  \' >&3
+
+exec 3>&-
 
 cd ..
 tar cvf - ${tag} | gzip --best > ${top_builddir}/autoopts/${tag}.tar.gz
