@@ -6,9 +6,9 @@
  * Maintainer:	       Gary V. Vaughan <gvv@techie.com>
  * Created:	       Thu Apr 22 23:13:34 1999
  * Last Modified:      Wed Aug  8 12:22:14 2001
- *            by:      Gary V. Vaughan <gary@gnu.org>
+ *            by: bkorb
  * ---------------------------------------------------------------------
- * @(#) $Id: format.c,v 1.10 2001/08/11 17:53:57 bkorb Exp $
+ * @(#) $Id: format.c,v 1.10 2002/06/20 22:58:38 bkorb Exp $
  * ---------------------------------------------------------------------
  */
 
@@ -161,6 +161,20 @@ static int	format_number	PARAMS((printfv_parser * const pparser,
 #define ISSET(field, flag)	((field)&(flag))
 
 
+#ifndef INT_MIN
+static int INT_MIN = 0;
+static int INT_MAX = 0;
+
+int
+snv_init_min_max(  )
+{
+    int v = 1UL << ((sizeof( int ) * 8) - 1);
+    INT_MIN = v;
+    INT_MAX = ~v;
+    return 0;
+}
+#endif
+
 static inline char
 fetch_space_defaulted_char (pparser, key)
     printfv_parser *pparser;
